package com.xtd.project.assets.mapper;

import java.util.List;
import com.xtd.project.assets.domain.DbAssetsStockScrap;

/**
 * 资产报废Mapper接口
 * 
 * @author xtd
 * @date 2020-04-17
 */
public interface DbAssetsStockScrapMapper 
{
    /**
     * 查询资产报废
     * 
     * @param aId 资产报废ID
     * @return 资产报废
     */
    public DbAssetsStockScrap selectDbAssetsStockScrapById(Long aId);

    /**
     * 查询资产报废列表
     * 
     * @param dbAssetsStockScrap 资产报废
     * @return 资产报废集合
     */
    public List<DbAssetsStockScrap> selectDbAssetsStockScrapList(DbAssetsStockScrap dbAssetsStockScrap);

    /**
     * 新增资产报废
     * 
     * @param dbAssetsStockScrap 资产报废
     * @return 结果
     */
    public int insertDbAssetsStockScrap(DbAssetsStockScrap dbAssetsStockScrap);

    /**
     * 修改资产报废
     * 
     * @param dbAssetsStockScrap 资产报废
     * @return 结果
     */
    public int updateDbAssetsStockScrap(DbAssetsStockScrap dbAssetsStockScrap);

    /**
     * 删除资产报废
     * 
     * @param aId 资产报废ID
     * @return 结果
     */
    public int deleteDbAssetsStockScrapById(Long aId);

    /**
     * 批量删除资产报废
     * 
     * @param aIds 需要删除的数据ID
     * @return 结果
     */
    public int deleteDbAssetsStockScrapByIds(Long[] aIds);
}
